#
# $Id$
#
# This program is free software; you can redistribute it and/or 
# modify it under the terms of the GNU General Public License, version 2.
#
# Infobrowser support for a generic filter of RSS feeds - only RSS entries which contain a search word will be displayed
#
package Plugins::InfoBrowserAddons::RSSFeedFilter::RSSFeedFilterParser;

# Parser for RSS Feeds

use strict;
use XML::Simple;
use Slim::Utils::Log;

my $log = logger('plugin.infobrowser');

sub getsearchword
{
	my $params = shift;
	my $searchword;

	my $clienttype	= 	defined( $params->{'item'}->{'lookfor'} )	? 'OPMLfile'
			:	defined( $params->{'request'} )			? 'Jive'
			:	defined( $params->{'args'} )			? 'WebUI'
			:	defined( $params->{'client'} )			? 'SB'
			:							  'Unknown' ;

	SWITCH:	{
		if ( $clienttype eq 'OPMLfile') {
			$searchword = $params->{'item'}->{'lookfor'};
			last SWITCH;
		}

		if ( $clienttype eq 'Jive') {

			my $request = $params->{'request'};
			my $client  = $request->client;
			$searchword = $request->getParam('search') ;
			if (defined($searchword)) {
				$client->pluginData( searchword => $searchword );
			} 

			$searchword = $client->pluginData('searchword');
			last SWITCH;
		}

		if ( $clienttype eq 'WebUI') {

			my ( $argsClient, $argsStash, $argsCallback, $argsHttpClient, $argsResponse ) = @{ $params->{'args'} };

			if (defined ($argsStash->{'q'}) ) {
				$searchword = $argsStash->{'q'};
			} else {
				if ( $params->{'currentIndex'}->[-1] =~ /\d+_(.+)/ ) {
					$searchword = $1;
				}
			}

			last SWITCH;
		}

		if ( $clienttype eq 'SB') {
			$searchword = $params->{'feedTitle'};
			last SWITCH;
		}

		$log->error(" Unknown search client type: $clienttype ");
		return undef;
	};

	$log->info(" Search client type: $clienttype   Search phrase: $searchword");

	return $searchword;
}



sub parse 
{

	my $class  = shift;
	my $http   = shift;
	my $params = $http->params('params');

	my @entries;
	my $items;

	my $lookforpattern;
#	my $lookfor;

	my $usersearchword = lc( getsearchword($params));
	return undef unless defined($usersearchword);


	my $xml    = XMLin(${$http->contentRef}, 'forcearray' =>  [qw(item outline entry)], 'keyattr' => []);

	$lookforpattern = qr/$usersearchword/;


	if ($xml->{'item'}) {
		$items = $xml->{'item'};
	} else {
		$items = $xml->{'channel'}->{'item'};
	}

	for my $itemXML (@$items) {
		my $texttosearch = lc( $itemXML->{'title'} . ' ' . $itemXML->{'description'}  );
		if ($texttosearch =~ m/$lookforpattern/ ) {
			push @entries, {
				'name' 		=> Slim::Formats::XML::unescapeAndTrim($itemXML->{'title'}),
				'description'	=> Slim::Formats::XML::unescapeAndTrim($itemXML->{'description'}) . ' ' 
						.  Slim::Formats::XML::unescapeAndTrim($itemXML->{'pubDate'}),
			};
		}
	}
	$log->info(sprintf("Matched %d item ",scalar(@entries))) ;

	if (scalar(@entries) == 0 ){
			push @entries, {
				'name' 		=> "Nothing found for : $usersearchword",
				'description'	=> "Nothing found for : $usersearchword in" . scalar(@$items) . " RSS entries",
			};
	}
	
	return {
		'type'  => 'opml',
		'title' => $params->{'feedTitle'},
		'items' => [@entries],
		'nocache' => 1,

	};
}
# Local Variables:
# tab-width:4
# indent-tabs-mode:t
# End:

1;
